---
title: Second Meetup in Bregenz
id: 2
date:  2024-05-22
author:  Max Mustermann
slug: first-meetup
status: Open
featureimage: fatureimage.png
address: Kunsthaus Bregenz, Karl-Tizian-Platz, 6900 Bregenz, Austria
description: Meetup2 description
---

## Details
Details about the event

## Agenda
Agenda Goes here. 

## About
About the speaker

## See you soon!
Don't miss out on this opportunity to learn, network, and have fun with others. We are always looking for speaker. If you have any ideas or suggestions, please don't hesitate to let us know. We look forward to seeing you at the next meetup!